## Typing stubs for networkx

This is a [type stub package](https://typing.python.org/en/latest/tutorials/external_libraries.html)
for the [`networkx`](https://github.com/networkx/networkx) package. It can be used by type checkers
to check code that uses `networkx`. This version of
`types-networkx` aims to provide accurate annotations for
`networkx==3.5`.

This package is part of the [typeshed project](https://github.com/python/typeshed).
All fixes for types and metadata should be contributed there.
See [the README](https://github.com/python/typeshed/blob/main/README.md)
for more details. The source for this package can be found in the
[`stubs/networkx`](https://github.com/python/typeshed/tree/main/stubs/networkx)
directory.

This package was tested with the following type checkers:
* [mypy](https://github.com/python/mypy/) 1.16.1
* [pyright](https://github.com/microsoft/pyright) 1.1.403

It was generated from typeshed commit
[`d270bb0dc1df3fcfae2808c9a5a0f7ec802e1fb2`](https://github.com/python/typeshed/commit/d270bb0dc1df3fcfae2808c9a5a0f7ec802e1fb2).